#!/bin/csh
# /etc/profile.d/zzzz_no_colorls.csh: v2 2008/11/17 KELEMEN Peter <Peter.Kelemen@cern.ch>

# Objective: strip --color=(always|auto|force|if-tty|tty|yes) options from
# aliases that call ls(1).  Keep old aliases with "__color_" prefix.

# Rationale: potentially saves lots of stat() calls that ls(1) issues to
# determine file type for coloring, which are a pain on busy AFS clients.

# Check if there are any aliases with "ls" defined.
set __x=` alias | grep -w ls | sed 's/\t.*$//' `
if ( $#__x != 0) then

	# Check and store globbing status, disable globbing.
	set __noglob=0
	if ( $?noglob ) then
		set __noglob=1
	else
		set noglob
	endif

	# Loop over potential aliases for processing.
	set __c=__color_
	foreach i ($__x)

		# Skip over aliases that probably we have created in a previous run.
		switch ("$i")
			case ${__c}*:
				continue
			breaksw
		endsw

		# Fetch alias definition.
		set __a=`alias $i `

		# Process alias word by word.
		set __m=0
		set __n=""
		foreach j ($__a)
			switch ($j)
				# Strip option (by excluding it from construction).
				case --color=always:
				case --color=auto:
				case --color=force:
				case --color=if-tty:
				case --color=tty:
				case --color=yes:
					set __m=1
					continue
				breaksw
				# Construct new command line.
				default:
					set __n="${__n} ${j}"
				breaksw
			endsw
		end

		# Bail out if we didn't find offending --color option.
		if ( $__m == 0) then
			continue
		endif

		# Save old alias.
		alias "${__c}${i}" "${__a}"

		# Create new alias.
		if ("$__n" == "ls") then
			# Get rid of useless collapsed alias.
			unalias "$i"
		else
			alias "${i}" "${__n}"
		endif
	end

	# Enable globbing if it was enabled originally.
	if ( $__noglob == 0 ) then
		unset noglob
	endif

	unset i
	unset j
	unset __noglob
	unset __a
	unset __c
	unset __m
	unset __n
	unset __x
endif

# End of file.
